package App::HistHub::Schema;

use strict;
use warnings;

use base 'DBIx::Class::Schema';

__PACKAGE__->load_classes;


# Created by DBIx::Class::Schema::Loader v0.04005 @ 2008-11-16 19:09:48
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:ramMDIevYbtGa2V7RiHhJA


# You can replace this text with custom content, and it will be preserved on regeneration
1;
