package App::HistHub::Web::View::TD;
use strict;
use warnings;
use base 'Catalyst::View::Template::Declare';

=head1 NAME

App::HistHub::Web::View::TD - Catalyst Template::Declare View

=head1 SYNOPSIS

See L<App::HistHub::Web>

=head1 DESCRIPTION

Catalyst Template::Declare View.

=head1 AUTHOR

Daisuke Murase

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
